@@ -1,3 +1,4 @@
+from typing import List
 from napari.layers.image.image import Image
 from napari.layers.points.points import Points
 from napari.layers.tracks.tracks import Tracks
@@ -11,6 +12,7 @@ import logging
 from mikro import gql
 import pandas as pd
 import numpy as np
+import dask.array as da
 
 logger = logging.getLogger(__name__)
 
@@ -188,6 +190,34 @@ class StageHelper(QObject):
 
         self.openMultiStack.emit([parent.data.squeeze()] + childrens, parent)
 
+    def open_aside(self, reps: List[Representation]):
+
+        query = gql(
+            """
+            query DetailRep($ids: [String]) {
+                representations(ids: $ids){
+                    name
+                    store
+                }
+            }
+            """
+        ).run(ids=reps)
+
+        max_shape = np.max([rep.data.shape for rep in reps], axis=0)
+        arrays = [da.zeros(max_shape) for rep in reps]
+        for index, array in enumerate(arrays):
+            array[
+                : reps[index].data.shape[0],
+                : reps[index].data.shape[1],
+                : reps[index].data.shape[2],
+                : reps[index].data.shape[3],
+                : reps[index].data.shape[4],
+            ] = reps[index].data
+
+        concatz = xr.DataArray(da.concatenate(arrays, axis=4)).compute()
+
+        self.openStack.emit(concatz, reps[0])
+
     def open_with_localizations(self, rep: Representation):
 
         query = gql(
