@@ -6,7 +6,6 @@ import numpy as np
 import argparse
 
 
-
 def main(**kwargs):
     viewer = napari.Viewer()
     widget = ArkitektWidget(viewer, **kwargs)
@@ -17,7 +16,9 @@ def main(**kwargs):
 if __name__ == "__main__":
 
     parser = argparse.ArgumentParser()
-    parser.add_argument('--config', help='Which config file to use', default="bergen.yaml", type=str)
+    parser.add_argument(
+        "--config", help="Which config file to use", default="bergen.yaml", type=str
+    )
     args = parser.parse_args()
 
     main(config_path=args.config)
